@@ -1,6 +1,6 @@
 ## Domain Registry Interface, XML-RPC Transport
 ##
-## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008-2011 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,23 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
-#
-# 
-#
 ####################################################################################################
 
 package Net::DRI::Transport::HTTP::XMLRPCLite;
 
-use base qw(Net::DRI::Transport);
 use strict;
+use warnings;
+
+use base qw(Net::DRI::Transport);
 
 use Net::DRI::Exception;
 use Net::DRI::Data::Raw;
 use Net::DRI::Util;
 use XMLRPC::Lite;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
-
 =pod
 
 =head1 NAME
@@ -55,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008-2011 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,17 +67,26 @@ See the LICENSE file that comes with this distribution for more details.
 ####################################################################################################
 sub new
 {
- my $class=shift;
- my $ctx=shift;
+ my ($class,$ctx,$rp)=@_;
+ my %opts=%$rp;
  my $po=$ctx->{protocol};
 
- my %opts=(@_==1 && ref($_[0]))? %{$_[0]} : @_;
+ my %t=(message_factory => $po->factories()->{message});
+ if (exists($opts{protocol_connection}) && $opts{protocol_connection})
+ {
+  $t{protocol_connection}=$opts{protocol_connection};
+  $t{protocol_connection}->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$t{protocol_connection},$@);
+  if ($t{protocol_connection}->can('transport_default'))
+  {
+   %opts=($t{protocol_connection}->transport_default('xmlrpclite'),%opts);
+  }
+ }
+
  my $self=$class->SUPER::new($ctx,\%opts); ## We are now officially a Net::DRI::Transport instance
  $self->is_sync(1);
  $self->name('xmlrpclite');
- $self->version($VERSION);
+ $self->version('0.1');
 
- my %t=(message_factory => $po->factories()->{message});
  $t{has_login}=(exists($opts{has_login}) && defined($opts{has_login}))? $opts{has_login} : 0;
  $t{has_logout}=(exists($opts{has_logout}) && defined($opts{has_logout}))? $opts{has_logout} : 0;
  $self->has_state($t{has_login});
@@ -94,7 +100,7 @@ sub new
   $t{session_data}={};
  }
 
- foreach my $p (qw/protocol_connection wsdl_uri proxy_uri servicename portname/)
+ foreach my $p (qw/protocol_connection proxy_uri/)
  {
   Net::DRI::Exception::usererr_insufficient_parameters($p.' must be provided') unless (exists($opts{$p}) && defined($opts{$p}));
   $t{$p}=$opts{$p};
@@ -102,7 +108,6 @@ sub new
  Net::DRI::Exception::usererr_invalid_parameters('proxy_uri must be http:// or https://') unless ($t{proxy_uri}=~m!^https?://!);
 
  my $pc=$t{protocol_connection};
- $pc->require or Net::DRI::Exception::err_failed_load_module('transport/socket',$pc,$@);
  if ($t{has_login})
  {
   foreach my $m (qw/login parse_login extract_session/)
@@ -120,14 +125,13 @@ sub new
  }
 
  $self->{transport}=\%t;
- bless($self,$class);
 
  if ($self->has_state())
  {
   if ($self->defer()) ## we will open, but later
   {
    $self->current_state(0);
-  } else ## we will open NOW 
+  } else ## we will open NOW
   {
    $self->open_connection($ctx);
   }
@@ -143,23 +147,13 @@ sub new
 sub soap { my ($self,$v)=@_; $self->{transport}->{soap}=$v if @_==2; return $self->{transport}->{soap}; }
 sub session_data { my ($self,$v)=@_; $self->{transport}->{session_data}=$v if @_==2; return $self->{transport}->{session_data}; }
 
-sub soap_fault
-{
- my($soap,$res)=@_; 
- my $msg=ref($res)? $res->faultstring() : $soap->transport()->status();
- Net::DRI::Exception->die(1,'transport/http/soapwsdl',7,'SOAP fault: '.$msg);
-}
-
 sub init
 {
  my ($self)=@_;
  return if defined($self->soap());
- my $soap=SOAP::WSDL->new()->on_fault(\&soap_fault);
- $soap->wsdl($self->{transport}->{wsdl_uri});
+ my $soap=XMLRPC::Lite->new();
  $soap->proxy($self->{transport}->{proxy_uri});
- $soap->wsdlinit();
- $soap->servicename($self->{transport}->{servicename});
- $soap->portname($self->{transport}->{portname});
+ $soap->transport()->agent(sprintf('Net::DRI/%s ',$Net::DRI::VERSION).$soap->transport()->agent());
  $self->soap($soap);
 }
 
@@ -174,12 +168,9 @@ sub send_login
  }
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$self->generate_trid();
+ my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
  my $login=$pc->login($t->{message_factory},$t->{client_login},$t->{client_password},$cltrid);
- my $res=$self->soap()->call( $login->method() => %{$login->params()});
- ## TODO logging
- Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send login message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
- ## TODO logging
+ my $res=$self->_send_receive({otype=>'session',oaction=>'login',trid=>$cltrid,phase=>'opening'},$login);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res]));
  my $rc=$pc->parse_login($msg);
@@ -190,17 +181,14 @@ sub send_login
 
 sub send_logout
 {
- my ($self,$ctx)=@_;
+ my ($self)=@_;
  my $t=$self->{transport};
  return unless $t->{has_logout};
 
  my $pc=$t->{protocol_connection};
- my $cltrid=$self->generate_trid();
+ my $cltrid=$self->generate_trid($self->{logging_ctx}->{registry});
  my $logout=$pc->logout($t->{message_factory},$cltrid,$t->{session_data});
- my $res=$self->soap()->call( $logout->method() => %{$logout->params()});
- ## TODO logging
- Net::DRI::Exception->die(1,'transport/soapwsdl',4,'Unable to send logout message due to SOAP fault: '.$res->faultcode().' '.$res->faultstring()) if ($res->fault());
- ## TODO logging
+ my $res=$self->_send_receive({otype=>'session',oaction=>'logout',trid=>$cltrid,phase=>'closing'},$logout);
  my $msg=$t->{message_factory}->();
  $msg->parse(Net::DRI::Data::Raw->new(1,[$res]));
  my $rc=$pc->parse_logout($msg);
@@ -209,6 +197,27 @@ sub send_logout
  $self->session_data({});
 }
 
+sub _send_receive
+{
+ my ($self,$ctx,$msg)=@_;
+ my $soap=$self->soap();
+ my $err;
+ my $res=$soap->on_fault(sub { (undef,$err)=@_; return; })->call($msg->method(),@{$msg->params()});
+ if (my $httpres=$soap->transport()->http_response())
+ {
+  $self->log_output('notice','transport',$ctx,{direction=>'out',message=>$httpres->request()});
+  $self->log_output('notice','transport',$ctx,{direction=>'in', message=>$httpres});
+ } else
+ {
+  $self->log_output('error','transport',$ctx,{direction=>'out',message=>'No response for message '.$soap->serializer()->envelope(method => $msg->method(), @{$msg->params()})});
+ }
+ return $res if defined $res && ref $res && ! $res->fault() && ! defined $err;
+
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP fault: '.$err->faultcode().' '.$err->faultstring()) if defined $err && ref $err;
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP transport error: '.$soap->transport()->status()) unless $soap->transport()->is_success();
+ Net::DRI::Exception->die(1,'transport/soaplite',4,'Unable to send message due to SOAP deserialization error: '.$err);
+}
+
 sub open_connection
 {
  my ($self,$ctx)=@_;
@@ -221,22 +230,22 @@ sub open_connection
 
 sub close_connection
 {
- my ($self,$ctx)=@_;
- $self->send_logout($ctx);
+ my ($self)=@_;
+ $self->send_logout();
  $self->soap(undef);
  $self->current_state(0);
 }
 
 sub end
 {
- my ($self,$ctx)=@_;
+ my ($self)=@_;
  if ($self->has_state() && $self->current_state())
  {
   eval
   {
    local $SIG{ALRM}=sub { die 'timeout' };
    alarm(10);
-   $self->close_connection($ctx);
+   $self->close_connection();
   };
   alarm(0); ## since close_connection may die, this must be outside of eval to be executed in all cases
  }
@@ -252,10 +261,10 @@ sub send
 
 sub _soap_send
 {
- my ($self,$count,$tosend)=@_;
+ my ($self,$count,$tosend,$ctx)=@_;
  my $t=$self->{transport};
- $tosend->add_session($self->session_data());
- my $res=$self->soap()->call( $tosend->method() => %{$tosend->params()});
+ $tosend->add_session($self->session_data()) if $tosend->can('add_session');
+ my $res=$self->_send_receive($ctx,$tosend);
  $t->{last_reply}=$res;
  return 1; ## very important
 }
@@ -272,7 +281,7 @@ sub _soap_receive
  my $t=$self->{transport};
  my $r=$t->{last_reply};
  $t->{last_reply}=undef;
- return Net::DRI::Data::Raw->new(1,[$r]);
+ return Net::DRI::Data::Raw->new(6,[$r]);
 }
 
 ####################################################################################################
